@@ -657,7 +657,7 @@ def populate_google_snapshot(snapshot, container=None):
                                             ('snapshotId', pymongo.ASCENDING)
                                         ]
                                     )
-                                insert_one_document(data, data['collection'], dbname)
+                                insert_one_document(data, data['collection'], dbname, check_keys=False)
                             else:
                                 snapshot_dir = make_snapshots_dir(container)
                                 if snapshot_dir:
